@@ -13,6 +13,14 @@ class Broker:
         self.cache = self.get_cache()
         self._info = None
 
+    def __getstate__(self):
+        return self.list_key, self._info
+
+    def __setstate__(self, state):
+        self.list_key, self._info = state
+        self.connection = self.get_connection(self.list_key)
+        self.cache = self.get_cache()
+
     def enqueue(self, task):
         """
         Puts a task onto the queue
@@ -176,7 +184,7 @@ def get_broker(list_key: str = Conf.PREFIX) -> Broker:
 
         return ironmq.IronMQBroker(list_key=list_key)
     # SQS
-    elif Conf.SQS:
+    elif type(Conf.SQS) == dict:
         from django_q.brokers import aws_sqs
 
         return aws_sqs.Sqs(list_key=list_key)
